==> paddlenlp-2.3.1-py3-none-any.whl: paddlenlp/datasets/hf_datasets/dureader_robust.py <==
# coding=utf-8
# Copyright (c) 2020 PaddlePaddle Authors. All Rights Reserved.
# Copyright 2020 The TensorFlow Datasets Authors and the HuggingFace Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Lint as: python3

import json
import os

import datasets
from datasets.tasks import QuestionAnsweringExtractive

logger = datasets.logging.get_logger(__name__)

_DESCRIPTION = """\
DureaderRobust is a chinese reading comprehension \
dataset, designed to evaluate the MRC models from \
three aspects: over-sensitivity, over-stability \
and generalization.
"""

_URL = "https://bj.bcebos.com/paddlenlp/datasets/dureader_robust-data.tar.gz"


class DureaderRobustConfig(datasets.BuilderConfig):
    """BuilderConfig for DureaderRobust."""

    def __init__(self, **kwargs):
        """BuilderConfig for DureaderRobust.

        Args:
          **kwargs: keyword arguments forwarded to super.
        """
        super(DureaderRobustConfig, self).__init__(**kwargs)


class DureaderRobust(datasets.GeneratorBasedBuilder):
    BUILDER_CONFIGS = [
        DureaderRobustConfig(
            name="plain_text",
            version=datasets.Version("1.0.0", ""),
            description="Plain text", ),
    ]

    def _info(self):
        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=datasets.Features({
                "id": datasets.Value("string"),
                "title": datasets.Value("string"),
                "context": datasets.Value("string"),
                "question": datasets.Value("string"),
                "answers": datasets.features.Sequence({
                    "text": datasets.Value("string"),
                    "answer_start": datasets.Value("int32"),
                }),
            }),
            # No default supervised_keys (as we have to pass both question
            # and context as input).
            supervised_keys=None,
            homepage="https://arxiv.org/abs/2004.11142",
            task_templates=[
                QuestionAnsweringExtractive(
                    question_column="question",
                    context_column="context",
                    answers_column="answers")
            ], )

    def _split_generators(self, dl_manager):
        dl_dir = dl_manager.download_and_extract(_URL)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": os.path.join(dl_dir, 'dureader_robust-data',
                                             'train.json')
                }),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={
                    "filepath": os.path.join(dl_dir, 'dureader_robust-data',
                                             'dev.json')
                }),
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={
                    "filepath": os.path.join(dl_dir, 'dureader_robust-data',
                                             'test.json')
                }),
        ]

    def _generate_examples(self, filepath):
        """This function returns the examples in the raw (text) form."""
        logger.info("generating examples from = %s", filepath)
        key = 0
        with open(filepath, encoding="utf-8") as f:
            durobust = json.load(f)
            for article in durobust["data"]:
                title = article.get("title", "")
                for paragraph in article["paragraphs"]:
                    context = paragraph[
                        "context"]  # do not strip leading blank spaces GH-2585
                    for qa in paragraph["qas"]:
                        answer_starts = [
                            answer["answer_start"]
                            for answer in qa.get("answers", '')
                        ]
                        answers = [
                            answer["text"] for answer in qa.get("answers", '')
                        ]
                        # Features currently used are "context", "question", and "answers".
                        # Others are extracted here for the ease of future expansions.
                        yield key, {
                            "title": title,
                            "context": context,
                            "question": qa["question"],
                            "id": qa["id"],
                            "answers": {
                                "answer_start": answer_starts,
                                "text": answers,
                            },
                        }
                        key += 1

==> paddlenlp-2.3.7-py3-none-any.whl: paddlenlp/datasets/hf_datasets/dureader_robust.py <==
# coding=utf-8
# Copyright (c) 2020 PaddlePaddle Authors. All Rights Reserved.
# Copyright 2020 The TensorFlow Datasets Authors and the HuggingFace Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Lint as: python3

import json
import os

import datasets
from datasets.tasks import QuestionAnsweringExtractive

logger = datasets.logging.get_logger(__name__)

_DESCRIPTION = """\
DureaderRobust is a chinese reading comprehension \
dataset, designed to evaluate the MRC models from \
three aspects: over-sensitivity, over-stability \
and generalization.
"""

_URL = "https://bj.bcebos.com/paddlenlp/datasets/dureader_robust-data.tar.gz"


class DureaderRobustConfig(datasets.BuilderConfig):
    """BuilderConfig for DureaderRobust."""

    def __init__(self, **kwargs):
        """BuilderConfig for DureaderRobust.

        Args:
          **kwargs: keyword arguments forwarded to super.
        """
        super(DureaderRobustConfig, self).__init__(**kwargs)


class DureaderRobust(datasets.GeneratorBasedBuilder):
    BUILDER_CONFIGS = [
        DureaderRobustConfig(
            name="plain_text",
            version=datasets.Version("1.0.0", ""),
            description="Plain text",
        ),
    ]

    def _info(self):
        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=datasets.Features({
                "id":
                datasets.Value("string"),
                "title":
                datasets.Value("string"),
                "context":
                datasets.Value("string"),
                "question":
                datasets.Value("string"),
                "answers":
                datasets.features.Sequence({
                    "text":
                    datasets.Value("string"),
                    "answer_start":
                    datasets.Value("int32"),
                }),
            }),
            # No default supervised_keys (as we have to pass both question
            # and context as input).
            supervised_keys=None,
            homepage="https://arxiv.org/abs/2004.11142",
            task_templates=[
                QuestionAnsweringExtractive(question_column="question",
                                            context_column="context",
                                            answers_column="answers")
            ],
        )

    def _split_generators(self, dl_manager):
        dl_dir = dl_manager.download_and_extract(_URL)

        return [
            datasets.SplitGenerator(name=datasets.Split.TRAIN,
                                    gen_kwargs={
                                        "filepath":
                                        os.path.join(dl_dir,
                                                     'dureader_robust-data',
                                                     'train.json')
                                    }),
            datasets.SplitGenerator(name=datasets.Split.VALIDATION,
                                    gen_kwargs={
                                        "filepath":
                                        os.path.join(dl_dir,
                                                     'dureader_robust-data',
                                                     'dev.json')
                                    }),
            datasets.SplitGenerator(name=datasets.Split.TEST,
                                    gen_kwargs={
                                        "filepath":
                                        os.path.join(dl_dir,
                                                     'dureader_robust-data',
                                                     'test.json')
                                    }),
        ]

    def _generate_examples(self, filepath):
        """This function returns the examples in the raw (text) form."""
        logger.info("generating examples from = %s", filepath)
        key = 0
        with open(filepath, encoding="utf-8") as f:
            durobust = json.load(f)
            for article in durobust["data"]:
                title = article.get("title", "")
                for paragraph in article["paragraphs"]:
                    context = paragraph[
                        "context"]  # do not strip leading blank spaces GH-2585
                    for qa in paragraph["qas"]:
                        answer_starts = [
                            answer["answer_start"]
                            for answer in qa.get("answers", '')
                        ]
                        answers = [
                            answer["text"] for answer in qa.get("answers", '')
                        ]
                        # Features currently used are "context", "question", and "answers".
                        # Others are extracted here for the ease of future expansions.
                        yield key, {
                            "title": title,
                            "context": context,
                            "question": qa["question"],
                            "id": qa["id"],
                            "answers": {
                                "answer_start": answer_starts,
                                "text": answers,
                            },
                        }
                        key += 1
